import re

from podcast_scraper.generic_parser import GenericParser


class FranceCulture(GenericParser):
    def get_urls(self, content):
        p = re.compile(r'data-url="(.+?\.mp3)"', flags=re.MULTILINE)
        m = p.findall(content)
        return m

    def get_next(self, webdriver):
        try:
            next = webdriver.find_element_by_css_selector(
                "#main-content > article > section > div.teasers-list > div.pager-container > ul > li.pager-item.next > a"
            )
            new_url = next.get_attribute("href")
            webdriver.get(new_url)
            return new_url
        except Exception as e:
            return False



import abc
import os

from selenium.webdriver import DesiredCapabilities
from testcontainers.selenium import BrowserWebDriverContainer


class GenericParser:
    @abc.abstractmethod
    def get_urls(self, content):
        ...

    @abc.abstractmethod
    def get_next(self, webdriver):
        ...

    def connect(self, webdriver, user, password):
        # dummy implementation, to be overrided
        pass

    def format_url(self, urls):
        for url in urls:
            print(url)

    def print_urls(self, url):
        with BrowserWebDriverContainer(DesiredCapabilities.CHROME) as chrome:
            webdriver = chrome.get_driver()
            webdriver.get(url)
            self.connect(
                webdriver, os.getenv("USER", None), os.getenv("PASSWORD", None)
            )
            content = webdriver.page_source
            self.format_url(self.get_urls(content))

            while bool(self.get_next(webdriver)):
                result = webdriver.page_source
                self.format_url(self.get_urls(result))
